VerticalCompactor class
Default vertical compaction (Gravity pulls up).
- Inheritance
-
- Object
- CompactorDelegate
- VerticalCompactor
Constructors
- VerticalCompactor()
-
Creates a new VerticalCompactor.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compact(
List< LayoutItem> layout, int cols, {bool allowOverlap = false}) → List<LayoutItem> -
Compacts the layout by removing gaps according to specific rules.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveCollisions(
List< LayoutItem> layout, int cols) → Layout -
Resolves overlaps by pushing items without necessarily compacting (pulling back).
Used primarily during drag operations to ensure validity without fighting the user.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited