ResizeHandle enum
An enum representing the different types of resize handles.
Each handle corresponds to a specific position on a widget's boundary, enabling resizing interactions in different directions. The available handles are:
- topLeft: Resizes from the top-left corner.
- top: Resizes from the top edge.
- topRight: Resizes from the top-right corner.
- left: Resizes from the left edge.
- right: Resizes from the right edge.
- bottomLeft: Resizes from the bottom-left corner.
- bottom: Resizes from the bottom edge.
- bottomRight: Resizes from the bottom-right corner.
Values
- topLeft → const ResizeHandle
-
Resizes from the top-left corner.
- top → const ResizeHandle
-
Resizes from the top edge.
- topRight → const ResizeHandle
-
Resizes from the top-right corner.
- left → const ResizeHandle
-
Resizes from the left edge.
- right → const ResizeHandle
-
Resizes from the right edge.
- bottomLeft → const ResizeHandle
-
Resizes from the bottom-left corner.
- bottom → const ResizeHandle
-
Resizes from the bottom edge.
- bottomRight → const ResizeHandle
-
Resizes from the bottom-right corner.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ResizeHandle> - A constant List of the values in this enum, in order of their declaration.